# Configuration of Hostapd as a RADIUS Server 



This document serves as a reference guide, demonstrating how to set up a RADIUS server for WPA2 Enterprise.   



### 1. Install Hostapd



```

$ sudo apt-get install libnl1 libnl-dev libnl-doc

$ sudo apt-get install libssl-dev

$ sudo apt-get install bridge-utils

$ sudo apt-get install hostapd

```



Once you install hostapd, you can use the following command to display its version:



```

hostapd -v

```



For example,  



```

hostapd v2.4

User space daemon for IEEE 802.11 AP management,

IEEE 802.1X/WPA/WPA2/EAP/RADIUS Authenticator

Copyright (c) 2002-2015, Jouni Malinen <j@w1.fi> and contributors

```



### 2. Configure Hostapd



Although `hostapd` provides a variety of services, only selected ones are used here. Please follow the steps below to configure `hostapd`.



Before starting configuration, check if there are any files in the `/etc/hostapd` directory and make sure that all the files are removed.  



#### 2.1 Configure Hostapd.conf



`hostapd.conf` is used to configure the hostapd methods. For the detailed configuration, please refer to [hostapd.conf](http://w1.fi/cgit/hostap/tree/hostapd/hostapd.conf?h=hostap_2_4).

  

Below is an example of `hostapd.conf` using `EAP-TLS`. Please create the file `hostapd.conf` with the sample code presented below and save it to the `/etc/hostapd/` directory, so the configuration specified in it will be effective when the hostapd is started.



```

driver=none # Indicates that no particular wireless/wired driver will be controlled

logger_syslog=-1

logger_syslog_level=2

logger_stdout=-1

logger_stdout_level=2

dump_file=/tmp/hostapd.dump

eap_server=1 # Enables EAP server

eap_user_file=/etc/hostapd/hostapd.eap_user # Configures users' eap parameters

ca_cert=/etc/hostapd/certs/ca.crt # Sets up the mutual authentication for the EAP-TLS method

server_cert=/etc/hostapd/certs/server.pem # Sets up the mutual authentication for the EAP-TLS method

private_key=/etc/hostapd/certs/server.key # Sets up the mutual authentication for the EAP-TLS method

radius_server_clients=/etc/hostapd/hostapd.radius_clients # Defines the authenticated radius client

radius_server_auth_port=1812 # Defines the authenticated radius port number

```



> Note:



> If the `EAP-PEAP` or `EAP-TTLS` method is used, please comment out the code line starting with `ca_cert`.





#### 2.2 Configure Hostapd.eap_user



`hostapd.eap_user` is used to configure the EAP method and the relevant parameters used for communication. For the detailed configuration, please refer to [hostapd.eap_user](http://w1.fi/cgit/hostap/tree/hostapd/hostapd.eap_user?h=hostap_2_4).

   

Below is an example of `hostapd.eap_user` using `EAP-TLS`. Please create the file `hostapd.eap_user` with the sample code presented below and save it to the `/etc/hostapd/` directory, so the configuration specified in it will be effective when the hostapd is started.



```

# hostapd user database for integrated EAP server

# This file enables all EAP methods used in WFA testing:

# EAP-TLS, EAP-TTLS/MSCHAPv2, PEAPv0/EAP-MSCHAPv2, PEAPv1/EAP-GTC, EAP-SIM, EAP-AKA, EAP-FAST

# Each line must contain identity, EAP method and optional password separated by Space or Tab characters. The identity and password parameters must be double quoted ("user").

# Phase 1 users:q

#*                      PEAP

#*                      TTLS

*                       TLS

# Phase 2 (tunnelled within EAP-PEAP/TTLS/FAST) users

#"user"         TTLS-MSCHAPV2                   "password"                      [2]

#"espressif"    TTLS-MSCHAPV2                   "test11"                        [2]

"user"          MSCHAPV2                        "password"                      [2]

"espressif"     MSCHAPV2                        "test11"                        [2]

#"*"    MSCHAPV2                        "*"                     [2]

```



> Note:



> * `*TLS`: `*` indicates that `identity` can be configured arbitrarily in Phase 1, and `TLS` indicates that the `TLS` method is used in this phase (Mutual authentication is required).

> * `[2]` in the rightmost column specifies the configurations to be used in Phase 2. The three left columns indicate `user name`, `EAP method` and `password` respectively.  

> 	* If the `EAP-PEAP` method is used, please add the code line starting with `* PEAP`.

> 	* If the `EAP-TTLS` method is used, please add the code lines starting with `* TTLS` and `#"espressif" TTLS-MSCHAPV2 "test11" [2]`.





#### 2.3 Configure Hostapd.radius_clients



`hostapd.radius_clients` is used to configure the RADIUS client. For the detailed configuration, please refer to [hostapd.radius_clients](http://w1.fi/cgit/hostap/tree/hostapd/hostapd.radius_clients?h=hostap_2_4).   



Here is an example of a random RADIUS client. It uses the password `12345678` to access `hostapd.radius_clients`, which is the configuration of a RADIUS server. To enable it, please save the following to the `/etc/hostapd/` directory:  



```

# IP of AS      pre-shared key

#192.168.0.139/24        radiusserverpasswd

0.0.0.0/0           12345678

```



#### 2.4 Configure Certificate-related Parameters



`hostapd.conf` contains the path where `ca_cert`, `server_cert` and `private_key` should be saved. Therefore, you should create a new directory `/etc/hostapd/certs` and save the ca certificate `ca.crt`, the server certificate `server.pem` and the private key `server.key` to this directory. 



### 3. Start Hostapd



```

sudo hostapd -dddt /etc/hostapd/hostapd.conf

```



* -ddd: Display more debugging information.

* -t: Display timestamp.



### 4. Configure AP



When all the above steps are completed, users may configure WPA2 Enterprise on APs.

   

You can take D-LINK as an example. Please see the `DIR-619L` configuration given below:  



![p2](https://img-blog.csdn.net/20180705211031521?watermark/2/text/aHR0cHM6Ly9ibG9nLmNzZG4ubmV0L2VzcHJlc3NpZg==/font/5a6L5L2T/fontsize/400/fill/I0JBQkFCMA==/dissolve/70)





* IP address of a RADIUS server should be configured manually to the IP address of the host machine that starts hostapd.   

* The port number should be manually configured to what has been specified in the `hostapd.conf` file, which is `1812`.

* The shared private key should be manually configured to what has been specified in the `hostapd.radius_clients` file, which is `12345678`.



### 5. Restart AP 



After the AP restarts, any device attempting to connect to D-Link should provide corresponding configuration parameters, such as `identity`, `user name`, and `password`. You may also modify the hostapd configuration to allow more services and permissions.  



